@@ -84,7 +84,7 @@ int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
 	}
 
 #ifdef GIT_EXPERIMENTAL_SHA256
-	error = git_indexer_new(&indexer, ".", GIT_OID_SHA1, NULL);
+	error = git_indexer_new(&indexer, ".", NULL);
 #else
 	error = git_indexer_new(&indexer, ".", 0, odb, NULL);
 #endif
