@@ -11,7 +11,9 @@ void test_refs_tags_name__is_name_valid(void)
 {
 	cl_assert_equal_i(true, name_is_valid("sometag"));
 	cl_assert_equal_i(true, name_is_valid("test/sometag"));
+	cl_assert_equal_i(true, name_is_valid("test/HEAD"));
 
 	cl_assert_equal_i(false, name_is_valid(""));
 	cl_assert_equal_i(false, name_is_valid("-dash"));
+	cl_assert_equal_i(false, name_is_valid("HEAD"));
 }
